@@ -12,10 +12,10 @@
 #ifndef KWINDOWINFO_H
 #define KWINDOWINFO_H
 
-#include <kwindowsystem_export.h>
-#include <QWidgetList> //For WId
 #include <QExplicitlySharedDataPointer>
 #include <QStringList>
+#include <QWidgetList> //For WId
+#include <kwindowsystem_export.h>
 
 #include <netwm_def.h>
 
@@ -556,6 +556,25 @@ public:
      **/
     QByteArray desktopFileName() const;
 
+    /**
+     * Returns the GTK application id of the window if present.
+     *
+     * This is comparable to desktopFileName.
+     *
+     * Requires NET::WM2GTKApplicationId passed as properties2 parameter to the constructor.
+     *
+     * @code
+     * QWidget *window = new QWidget(nullptr);
+     * window->show();
+     * KWindowInfo info(window->winId(), 0, NET::WM2GTKApplicationId);
+     * if (info.valid())
+     *     info.gtkApplicationId();
+     * @endcode
+     *
+     * @since 5.91
+     **/
+    QByteArray gtkApplicationId() const;
+
     /**
      * Returns the process ID of the window's application if present.
      *
@@ -566,7 +585,7 @@ public:
      * window->show();
      * KWindowInfo info(window->winId(), NET::WMPid);
      * if (info.valid())
-     *     info.desktopFileName();
+     *     info.pid();
      * @endcode
      *
      * @since 5.29
@@ -599,9 +618,9 @@ public:
      * Assignment operator.
      */
     KWindowInfo &operator=(const KWindowInfo &);
+
 private:
     QExplicitlySharedDataPointer<KWindowInfoPrivate> d;
 };
 
 #endif // multiple inclusion guard
-
